@@ -4,9 +4,10 @@
 from logging import getLogger
 
 import os
-import requests
+import sys
+import urllib.parse
 
-from ._compatimports import urlparse
+import requests
 
 
 log = getLogger(__name__)
@@ -21,10 +22,11 @@ class _BugzillaSession(object):
             tokencache, api_key, requests_session=None):
         self._url = url
         self._user_agent = user_agent
-        self._scheme = urlparse(url)[0]
+        self._scheme = urllib.parse.urlparse(url)[0]
         self._cookiecache = cookiecache
         self._tokencache = tokencache
         self._api_key = api_key
+        self._is_xmlrpc = False
 
         if self._scheme not in ["http", "https"]:
             raise Exception("Invalid URL scheme: %s (%s)" % (
@@ -41,7 +43,6 @@ class _BugzillaSession(object):
         if sslverify is False:
             self._session.verify = False
         self._session.headers["User-Agent"] = self._user_agent
-        self._session.params["Bugzilla_api_key"] = self._api_key
         self._set_tokencache_param()
 
     def _get_timeout(self):
@@ -52,6 +53,16 @@ class _BugzillaSession(object):
         envtimeout = os.environ.get("PYTHONBUGZILLA_REQUESTS_TIMEOUT")
         return float(envtimeout or DEFAULT_TIMEOUT)
 
+    def set_rest_defaults(self):
+        self._session.headers["Content-Type"] = "application/json"
+        # Bugzilla 5.0 only supports api_key as a query parameter.
+        # Bugzilla 5.1+ takes it as a X-BUGZILLA-API-KEY header as well,
+        # with query param taking preference.
+        self._session.params["Bugzilla_api_key"] = self._api_key
+    def set_xmlrpc_defaults(self):
+        self._is_xmlrpc = True
+        self._session.headers["Content-Type"] = "text/xml"
+
     def get_user_agent(self):
         return self._user_agent
     def get_scheme(self):
@@ -63,8 +74,6 @@ class _BugzillaSession(object):
     def set_token_value(self, value):
         self._tokencache.set_value(self._url, value)
         self._set_tokencache_param()
-    def set_content_type(self, value):
-        self._session.headers["Content-Type"] = value
 
     def _set_tokencache_param(self):
         if self._api_key:
@@ -89,4 +98,21 @@ class _BugzillaSession(object):
         timeout = self._get_timeout()
         if "timeout" not in kwargs:
             kwargs["timeout"] = timeout
-        return self._session.request(*args, **kwargs)
+
+        response = self._session.request(*args, **kwargs)
+
+        if self._is_xmlrpc:
+            # Yes this still appears to matter for properly decoding unicode
+            # code points in bugzilla.redhat.com content
+            response.encoding = "UTF-8"
+            # Set response cookies
+            self.set_response_cookies(response)
+
+        try:
+            response.raise_for_status()
+        except Exception as e:
+            # Scrape the api key out of the returned exception string
+            message = str(e).replace(self._api_key or "", "")
+            raise type(e)(message).with_traceback(sys.exc_info()[2])
+
+        return response
