@@ -6,8 +6,6 @@
 # bug_autorefresh.py: Show what bug_autorefresh is all about, and explain
 #   how to handle the default change via python-bugzilla in 2016
 
-from __future__ import print_function
-
 import bugzilla
 
 # public test instance of bugzilla.redhat.com. It's okay to make changes
@@ -51,6 +49,6 @@ except AttributeError:
 # Why does this matter? Some scripts are implicitly depending on this
 # auto-refresh behavior, because their include_fields specification doesn't
 # cover all attributes they actually use. Your script will work, sure, but
-# it's likely doing many more XML-RPC calls than needed, possibly 1 per bug.
+# it's likely doing many more API calls than needed, possibly 1 per bug.
 # So if after upgrading python-bugzilla you start hitting issues, the
 # recommendation is to fix your include_fields.
