@@ -1,16 +1,11 @@
 #!/usr/bin/env python
 #
-# This program is free software; you can redistribute it and/or modify it
-# under the terms of the GNU General Public License as published by the
-# Free Software Foundation; either version 2 of the License, or (at your
-# option) any later version.  See http://www.gnu.org/copyleft/gpl.html for
-# the full text of the license.
+# This work is licensed under the GNU GPLv2 or later.
+# See the COPYING file in the top-level directory.
 
 # getbug.py: Simple demonstration of connecting to bugzilla, fetching
 #            a bug, and printing some details.
 
-from __future__ import print_function
-
 import pprint
 
 import bugzilla
