@@ -9,8 +9,6 @@
 Unit tests that do permanent functional against a real bugzilla instances.
 """
 
-from __future__ import print_function
-
 import datetime
 import inspect
 import os
@@ -98,7 +96,7 @@ def test03NewBugBasic(run_cli, backends):
     assert hasattr(bug, "bug_id")
 
     # Close the bug
-    run_cli("bugzilla modify --close NOTABUG %s" % bug.id, bz)
+    run_cli("bugzilla modify --close NOTABUG %s --minor-update" % bug.id, bz)
     bug.refresh()
     assert bug.status == "CLOSED"
     assert bug.resolution == "NOTABUG"
@@ -575,7 +573,7 @@ def _test8Attachments(run_cli, backends):
     out = run_cli(cmd + "--getall %s" % getbug.id, bz).splitlines()
 
     assert len(out) == numattach
-    fnames = [l.split(" ", 1)[1].strip() for l in out]
+    fnames = [line.split(" ", 1)[1].strip() for line in out]
     assert len(fnames) == numattach
     for f in fnames:
         if not os.path.exists(f):
@@ -587,7 +585,7 @@ def _test8Attachments(run_cli, backends):
     out = run_cli(ignorecmd, bz).splitlines()
 
     assert len(out) == (numattach - 1)
-    fnames = [l.split(" ", 1)[1].strip() for l in out]
+    fnames = [line.split(" ", 1)[1].strip() for line in out]
     assert len(fnames) == (numattach - 1)
     for f in fnames:
         if not os.path.exists(f):
@@ -902,6 +900,12 @@ def test15EnsureLoggedIn(run_cli, backends):
     comm = "bugzilla --ensure-logged-in query --bug_id 979546"
     run_cli(comm, bz)
 
+    # Test that we don't pollute the query dict with auth info
+    query = {"id": [1234567]}
+    origquery = query.copy()
+    bz.query(query)
+    assert query == origquery
+
 
 def test16ModifyTags(run_cli, backends):
     bugid = "461686"
